import axios from 'axios';
import Debug from 'debug';
const debug = Debug('hasura');
export class HasuraApi {
    options;
    defaultErrorHandler = (result) => console.log('error', result?.error, result?.data);
    constructor(options) {
        this.options = { errorHandler: this.defaultErrorHandler, ...options };
    }
    validateStatus() { return true; }
    ;
    getError(result) {
        const { status } = result;
        const error = status >= 200 && status < 300 ? null : result.statusText;
        return error;
    }
    sql(sql) {
        return this.query({
            type: 'run_sql',
            args: {
                sql,
            },
        }, {
            route: '/v1/query',
        });
    }
    explain(query) {
        return this.query({
            query: {
                query
            },
        }, {
            route: '/v1/graphql/explain',
        });
    }
    async query(data, options = { route: '/v1/query' }) {
        debug('query', data?.type);
        const result = await axios({
            method: 'post',
            url: `http${this.options.ssl ? 's' : ''}://${this.options.path}${options?.route}`,
            headers: {
                ...(this.options.secret ? { 'x-hasura-admin-secret': this.options.secret } : {}),
            },
            data,
            validateStatus: this.validateStatus,
        });
        result.error = this.getError(result);
        if (result.error)
            this.options.errorHandler(result);
        return result;
    }
    async metadata(data, options = { route: '/v1/metadata' }) {
        return await this.query(data, options);
    }
}
